.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

¡Bienvenidos Al Tutorial De Sage!
=================================

Sage es un software matemático libre y de código abierto que apoya la investigación y
la enseñanza en álgebra, geometría, teoría de números, criptografía,
computación numérica y áreas relacionadas. Tanto el modelo de desarrollo
como la tecnología en Sage se distinguen por un énfasis extremadamente fuerte
en la apertura, comunidad, cooperación y colaboración: estamos construyendo el
carro, no reinventando la rueda.
La meta de Sage en su conjunto es la de crear una alternativa viable, libre y de
código abierto a Maple, Mathematica, Magma y MATLAB.

Este tutorial es la mejor manera de familiarizarse con Sage en unas cuantas
horas. Puedes leerlo en versión HTML o PDF, o desde el notebook de Sage
(haz click en ``Help``, luego haz click en ``Tutorial`` para trabajar
interactivamente en el tutorial desde dentro de Sage).

Este trabajo está licenciado bajo una licencia `Creative Commons Attribution-Share Alike
3.0`__.

__ http://creativecommons.org/licenses/by-sa/3.0/

.. toctree::
   :maxdepth: 2

   introduction
   tour

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

